pub struct FairWorkTurn { /* private fields */ }Expand description
One process-fair work turn. Dropping an unfinished turn reconciles the scheduler with zero work and without requeueing, so task cancellation can never strand the global scheduler in an in-flight state.
Implementations
Sourceimpl FairWorkTurn
impl FairWorkTurn
pub fn allowance(&self) -> FairBudget
pub fn complete( self, used: FairBudget, still_ready: bool, ) -> Result<(), FairnessError>