pub struct TaskSupervisor { /* private fields */ }Implementations
Sourceimpl TaskSupervisor
impl TaskSupervisor
pub fn snapshot(&self, class: TaskClass) -> TaskClassSnapshot
pub fn active_total(&self) -> usize
pub fn active_scoped(&self) -> usize
Sourcepub async fn wait_empty(&self)
pub async fn wait_empty(&self)
Wait until this RuntimeContext’s accounting scope owns no supervised tasks. The notification is armed before observation so the final task cannot exit between the check and await.
pub fn drain_terminal_reports(&self) -> Vec<TaskTerminalReport>
pub fn dropped_terminal_reports(&self) -> u64